@@ -802,7 +802,7 @@ class PkgManagerBom:
         hub_version = self.hub_api.get_hub_version()
         logging.info("BLACK DUCK VERSION IS {}".format(hub_version))
         vers_result = hub_version.split(".")
-        if int(vers_result[0]) >= 2021 and int(vers_result[1]) >= 6:
+        if (int(vers_result[0]) >= 2021 and int(vers_result[1]) >= 6) or int(vers_result[0]) >= 2022:
             self.direct_match_evidence = 'DIRECT_DEPENDENCY_BINARY'
             self.transitive_match_evidence = 'TRANSITIVE_DEPENDENCY_BINARY'
         else:
