@@ -4,12 +4,19 @@ Use subject to the terms and conditions of the Synopsys End User Software Licens
 All rights reserved worldwide.
 """
 
-import sys
-import os
-import logging
+import glob
 import json
+import logging
+import os
+import pkg_resources
+import platform
+import re
 import shlex
+import stat
+import subprocess
+import sys
 from datetime import datetime
+from os.path import expanduser
 from blackduck_c_cpp.util import util
 from blackduck_c_cpp.util.c_arg_parser import C_Parser
 from blackduck_c_cpp.pkg_manager.pkg_manager_detector import PkgDetector
@@ -21,13 +28,6 @@ from blackduck_c_cpp.sig_scanner.run_sig_scanner import SigScanner
 from blackduck_c_cpp.util.hub_api import HubAPI
 from blackduck_c_cpp.coverity_json.cov_json_parse import CovJsonParser
 from blackduck_c_cpp.util.cov_install import CoverityInstall
-import glob
-import platform
-import re
-from os.path import expanduser
-import pkg_resources
-import stat
-import subprocess
 
 """
 This class will run coverity build capture for the supplied build command.
@@ -43,18 +43,20 @@ class RunBuildCapture(object):
         self.start_time = datetime.now()
         self.blackduck_c_cpp_version = self.get_package_version()
         self.home = expanduser("~")
-        self.bld_dir = self.my_args.args.build_dir
+        self.bld_dir = util.get_absolute_path(self.my_args.args.build_dir)
         self.bld_cmd = self.my_args.args.build_cmd
         self.hub_project_name = self.my_args.args.project_name
         self.hub_project_vers = shlex.quote(self.my_args.args.project_version)
-        self.cov_dir = self.my_args.args.cov_output_dir if self.my_args.args.cov_output_dir else os.path.join(self.home,
+        self.cov_dir = util.get_absolute_path(self.my_args.args.cov_output_dir) if self.my_args.args.cov_output_dir else os.path.join(self.home,
                                                                                                               ".synopsys",
                                                                                                               "blackduck-c-cpp",
                                                                                                               "output",
                                                                                                               self.hub_project_name)
-        self.blackduck_output_dir = blackduck_output_dir
+        self.blackduck_output_dir = util.get_absolute_path(blackduck_output_dir)
         self.skip_build = my_args.args.skip_build
+        self.port = my_args.args.port
         self.bd_url = shlex.quote(self.my_args.args.bd_url.strip('/'))
+        self.bd_url_with_port = '{}:{}'.format(self.bd_url, self.port)
         self.codelocation_name = shlex.quote(
             self.my_args.args.codelocation_name) if self.my_args.args.codelocation_name else "{}/{}".format(
             self.hub_project_name, self.hub_project_vers)
@@ -70,7 +72,7 @@ class RunBuildCapture(object):
         self.skip_dynamic = self.my_args.args.skip_dynamic
         self.use_offline_files = self.my_args.args.use_offline_files
         self.offline_mode = self.my_args.args.offline
-        self.scan_cli_dir = self.my_args.args.scan_cli_dir if self.my_args.args.scan_cli_dir is not None else self.blackduck_output_dir
+        self.scan_cli_dir = util.get_absolute_path(self.my_args.args.scan_cli_dir) if self.my_args.args.scan_cli_dir is not None else self.blackduck_output_dir
         self.cov_configure_args = my_args.args.cov_configure_args
         self.run_modes = list(map(lambda mode: mode.lower(), map(lambda s: re.sub("[\"\']", "", s),
                                                                  map(str.strip, self.my_args.args.modes.split(",")))))
@@ -79,8 +81,8 @@ class RunBuildCapture(object):
         self.SIG_MODE = 'sig'
         self.BDBA_MODE = 'bdba'
         self.ALL_MODE = 'all'
-        self.hub_api = HubAPI(self.bd_url, self.api_token, self.insecure)
-        self.log_path = log_path
+        self.hub_api = HubAPI(self.bd_url_with_port, self.api_token, self.insecure)
+        self.log_path = util.get_absolute_path(log_path)
         self.platform_name = platform.system().lower()
         self.cov_home = self.set_coverity_root()
         self.cov_bin = os.path.join(self.cov_home, "bin")
@@ -92,6 +94,7 @@ class RunBuildCapture(object):
         self.resolved_cov_files_list = os.path.join(self.blackduck_output_dir, "resolved_cov_file_paths.txt")
         self.unresolved_cov_files_list = os.path.join(self.blackduck_output_dir, "unresolved_cov_file_paths.txt")
         self.cov_json_file_path = os.path.join(self.blackduck_output_dir, "cov_emit_links.json")
+        self.bazel = my_args.args.bazel
 
     def __enter__(self):
         if not self.offline_mode:
@@ -103,7 +106,10 @@ class RunBuildCapture(object):
         logging.info("RUNNING BLACKDUCK-C-CPP VERSION {}".format(self.blackduck_c_cpp_version))
         logging.info("Output log is written to file {}".format(os.path.join(self.log_path)))
         logging.info("coverity output files will be in {}".format(self.cov_dir))
-        logging.debug("Arguments passed into blackduck-c-cpp are {}".format(self.my_args.args))
+
+        args_to_print = self.my_args.args
+        args_to_print.api_token = '*********'
+        logging.debug("Arguments passed into blackduck-c-cpp are {}".format(args_to_print))
 
         offline_yaml_location = os.path.join(self.blackduck_output_dir, "offline_config.yaml")
         if self.offline_mode:
@@ -186,6 +192,41 @@ class RunBuildCapture(object):
         print()  # line break between phases for readability
         logging.info("******************************   Phase: {} ***********************************".format(phase))
 
+    def find_bazel_workspace_file(self):
+        bazel_workspace_files = glob.glob(os.path.join(self.bld_dir, 'WORKSPACE*'), recursive=False)
+        if len(bazel_workspace_files) != 1:
+            if not bazel_workspace_files:
+                logging.warning("The Bazel WORKSPACE file was not found so the required modification can't be verified.")
+            else:
+                logging.warning("Multiple possible WORKSPACE files were found.")
+            logging.warning("If the Bazel WORKSPACE file has already been modified manually to work with Coverity, ignore this warning. Otherwise, see the Bazel Setup > Modify project files > Workspace file section in the PyPi documentation for instructions.")
+            return None
+        return bazel_workspace_files[0]
+
+    def modify_bazel_workspace_file(self):
+        """
+        Modify the workspace file for bazel build if need be
+        """
+        bazel_workspace_file = self.find_bazel_workspace_file()
+        if bazel_workspace_file:
+            with open(bazel_workspace_file, 'r') as f:
+                contents = f.read()
+                if 'rules_coverity' in contents:
+                    logging.debug("The bazel WORKSPACE file appears to have been already updated to work with Coverity and will not be modified")
+                    return
+            with open(bazel_workspace_file, 'a') as f:
+                logging.info("The bazel WORKSPACE file does not have the required modification and will be updated")
+                update_string = 'load("@bazel_tools//tools/build_defs/repo:http.bzl", "http_archive")' + os.linesep \
+                                + 'http_archive(' + os.linesep \
+                                + '    name="rules_coverity",' + os.linesep \
+                                + '    urls=["file:///{}"],'.format(os.path.join(self.cov_home, 'bazel', 'rules_coverity.tar.gz')) + os.linesep \
+                                + ')' + os.linesep + os.linesep \
+                                + 'load("@rules_coverity//coverity:repositories.bzl", "rules_coverity_toolchains")' + os.linesep \
+                                + 'rules_coverity_toolchains()'
+                f.write(update_string)
+                logging.debug("Text appended to WORKSPACE file:")
+                logging.debug(update_string)
+
     def get_cov_version(self, cov_home):
         cmd = os.path.join(cov_home, "bin", "cov-build") + ' --ident'
         out = subprocess.getstatusoutput(cmd)
@@ -199,7 +240,7 @@ class RunBuildCapture(object):
         self.log_phase("Get coverity root information")
         if self.my_args.args.coverity_root and os.path.exists(self.my_args.args.coverity_root):
             logging.debug("Using coverity package given by user")
-            cov_home = self.my_args.args.coverity_root
+            cov_home = util.get_absolute_path(self.my_args.args.coverity_root)
         else:
             cov_home = self.coverity_download()
         logging.info("coverity files are at {}".format(cov_home))
@@ -229,6 +270,10 @@ class RunBuildCapture(object):
         sys.excepthook = self.handle_uncaught_exp
         start_build = datetime.now()
         cov_conf = os.path.join(self.blackduck_output_dir, "conf")
+        build_command = self.bld_cmd
+
+        # archive emit directory to keep old results out of new scans
+        EmitWrapper(self.cov_home, self.cov_dir, self.blackduck_output_dir, self.platform_name).archive_emit_dir()
 
         # to write build command to script
         if not os.path.exists(self.bld_cmd):
@@ -254,6 +299,8 @@ class RunBuildCapture(object):
 
         conf_cmd = util.conf_cmd("--clang", self.cov_bin, cov_conf)
         conf_cmd += conf_key + util.conf_cmd("--msvc", self.cov_bin, cov_conf)
+        if self.bazel:
+            conf_cmd += conf_key + util.conf_cmd("--gcc", self.cov_bin, cov_conf)
 
         conf_cmd += conf_key + util.conf_cmd("--template --compiler cc --comptype gcc", self.cov_bin, cov_conf)
         conf_cmd += conf_key + util.conf_cmd("--template --compiler *gcc* --comptype gcc", self.cov_bin, cov_conf)
@@ -274,12 +321,17 @@ class RunBuildCapture(object):
             cov_add_cmd = ''
 
         if os.path.exists(cov_emit_link_path):
-            self.bld_cmd = '"{}" --emit-link-units -c "{}" --dir "{}" --record-with-source{} "{}"'.format(cov_build_path,
+            self.bld_cmd = '"{}" --emit-link-units -c "{}" --dir "{}" {} '.format(cov_build_path,
                                                                                      os.path.join(cov_conf, "bld.xml"),
-                                                                                     self.cov_dir, cov_add_cmd, sh_path)
+                                                                                     self.cov_dir, cov_add_cmd)
         else:
-            self.bld_cmd = '"{}" -c "{}" --dir "{}" --record-with-source{} "{}"'.format(cov_build_path, os.path.join(cov_conf, "bld.xml"),
-                                                                   self.cov_dir, cov_add_cmd, sh_path)
+            self.bld_cmd = '"{}" -c "{}" --dir "{}" {} '.format(cov_build_path, os.path.join(cov_conf, "bld.xml"),
+                                                                   self.cov_dir, cov_add_cmd)
+
+        if self.bazel:
+            self.bld_cmd += ' --bazel {}'.format(build_command)
+        else:
+            self.bld_cmd += ' --record-with-source "{}"'.format(sh_path)
 
         full_cmd = conf_cmd + conf_key + self.bld_cmd
         logging.info("Build Command: {}".format(self.bld_cmd))
@@ -301,6 +353,7 @@ class RunBuildCapture(object):
         if not self.use_offline_files:
             blackduck_emit_wrapper = EmitWrapper(self.cov_home, self.cov_dir, self.blackduck_output_dir,
                                                  self.platform_name)
+            blackduck_emit_wrapper.run_cov_emit()
             emit_wrapper_output_sig = blackduck_emit_wrapper.cov_emit_output_sig
             emit_cov_header_files = blackduck_emit_wrapper.cov_header_files
         else:
@@ -434,7 +487,8 @@ class RunBuildCapture(object):
                                  self.my_args.args.scan_interval,
                                  self.my_args.args.json_splitter_limit,
                                  self.my_args.args.disable_json_splitter,
-                                 self.my_args.args.skip_includes)
+                                 self.my_args.args.skip_includes,
+                                 self.port)
         sig_scanner.run()
         end_sig = datetime.now()
         logging.info('Time taken to get sig results: {}'.format(end_sig - start_sig))
@@ -503,6 +557,9 @@ class RunBuildCapture(object):
 
         cov_emit_link_path = ""
 
+        if self.bazel:
+            self.modify_bazel_workspace_file()
+
         try:
             cov_build_path = glob.glob(os.path.join(self.cov_bin, 'cov-build*'))[0]
             cov_manage_emit_path = glob.glob(os.path.join(self.cov_bin, 'cov-manage-emit*'))[0]
@@ -517,6 +574,8 @@ class RunBuildCapture(object):
 
         # COV BUILD
         if not self.skip_build:
+            if self.bld_cmd == '':
+                util.error_and_exit("the following argument is required: -bc/--build_cmd")
             self.run_build(cov_emit_link_path, cov_build_path)
 
         # COV EMIT
