@@ -28,7 +28,7 @@ class SigScanner:
                  code_location_name, cov_emit_output_sig, blackduck_output_dir, offline_mode, scan_cli_dir,
                  use_offline_files, os_dist, additional_sig_scan_args, expand_sig_files, scan_interval,
                  json_splitter_limit,
-                 disable_json_splitter, skip_includes):
+                 disable_json_splitter, skip_includes, port):
         self.hub_api = hub_api
         self.sleep_interval = scan_interval  # time to wait between scans
         self.project_name = project_name
@@ -65,13 +65,15 @@ class SigScanner:
         self.proxy_settings = ''
         self.url_split = "://"
         self.op_sys = platform.system()
+        self.port = port
 
     def get_files_to_tar(self):
         """ collect all files to send to signature scanner"""
         if self.skip_includes:
             self.cov_emit_output_sig = [emit_file for emit_file in self.cov_emit_output_sig if not (
-                    re.match(global_settings.hpp_pattern, emit_file.strip()) or re.match(global_settings.h_pattern,
-                                                                                         emit_file.strip()))]
+                    re.match(global_settings.hpp_pattern, emit_file.strip()) or
+                    re.match(global_settings.hxx_pattern, emit_file.strip()) or
+                    re.match(global_settings.h_pattern, emit_file.strip()))]
         self.files_to_tar = set(self.cov_emit_output_sig)
         if self.files_notdetect_from_pkgmgr:
             [[[self.files_to_tar.add(path) for path in paths if os.path.exists(path)] for paths in type.values()] for
@@ -114,7 +116,8 @@ class SigScanner:
                 continue
             except Exception as e:
                 if len(dest_filepath) > 260 and self.op_sys == 'Windows':
-                    logging.warning("You are using Windows and the file path exceeds the default limit of 260 characters. Check the character limit on your system and consider removing the limit to include this file in the scan. The rest of the scan will proceed.")
+                    logging.warning(
+                        "You are using Windows and the file path exceeds the default limit of 260 characters. Check the character limit on your system and consider removing the limit to include this file in the scan. The rest of the scan will proceed.")
                     logging.warning("Not copying file to location: {}".format(dest_filepath))
                 else:
                     logging.error("Exception is {}".format(e))
@@ -295,9 +298,10 @@ class SigScanner:
         if self.offline_mode:
             sig_scanner_command += '--dryRunWriteDir "{}" '.format(self.sig_scan_output_directory)
         else:
-            if self.url_split in self.hub_api.hub.config['baseurl']:
-                scheme, host = self.hub_api.hub.config['baseurl'].split(self.url_split)
-                sig_scanner_command += '--scheme {} --host {} --port 443 '.format(scheme, host)
+            bd_url = self.hub_api.hub.config['baseurl'].strip(':{}'.format(self.port))
+            if self.url_split in bd_url:
+                scheme, host = bd_url.split(self.url_split)
+                sig_scanner_command += '--scheme {} --host {} --port {} '.format(scheme, host, self.port)
                 if self.insecure:
                     sig_scanner_command += '--insecure '
                 self.upload_dry_run = False
