@@ -18,7 +18,6 @@ from blackduck_c_cpp.util import global_settings
 
 class CoverityInstall:
     """Class to download latest coverity package for different OS """
-
     def __init__(self, cov_home, hub_api, platform, force, blackduck_c_cpp_version):
         hub_api.authenticate()
         self.hub_api = hub_api
@@ -35,6 +34,8 @@ class CoverityInstall:
         self.tool_token_json = None
         self.gcp_filepath = None
         self.blackduck_c_cpp_version = blackduck_c_cpp_version
+        self.min_cov_year_for_api = 2021
+        self.min_cov_vers_for_api = 10
         try:
             self.run()
         except Exception as e:
@@ -141,7 +142,8 @@ class CoverityInstall:
         """
         hub_version = self.hub_api.get_hub_version()
         vers_result = hub_version.split(".")
-        if (int(vers_result[0]) >= 2021 and int(vers_result[1]) >= 10) or int(vers_result[0]) >= 2022:
+        if ((int(vers_result[0]) >= self.min_cov_year_for_api and int(vers_result[1]) >= self.min_cov_vers_for_api) or int(
+                vers_result[0]) >= self.min_cov_year_for_api + 1):
             self.hub_api_tool_token()
             match_result = self.verify_checksum_match()
             if not match_result:
